@@ -164,7 +164,7 @@ to_map <- function(sdata, xlim=NULL, ylim=NULL, margin=10,
     
     #### Plot locations on the map
     p <- p +
-      geom_path(aes_string(x="lon", y="lat"), data=sdata.temp, colour=line.col, linetype = line.type, size=line.size)+
+      geom_path(aes_string(x="lon", y="lat"), data=sdata.temp, colour=line.col, linetype = line.type, linewidth=line.size)+
       geom_point(aes_string(x="lon", y="lat"), data=sdata.temp, size=point.size, colour=point.col, shape=point.symbol, fill=point.bg) +
       coord_fixed(xlim=xlim, ylim=ylim, ratio=1) + 
       theme_classic() + 
